@@ -1,6 +1,10 @@
 #!/usr/bin/bash
 set -eu
 
+#
+# Help with comparing outputs form AST tests.
+#
+
 readonly newline=$'\n'
 
 expected=''
@@ -8,7 +12,7 @@ actual=''
 
 current='expected'
 
-while read -r line; do
+while IFS= read -r line; do
 	if [[ $line == Actual:* ]]; then
 		current='actual'
 	fi
