@@ -2,7 +2,7 @@
  * data/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -21,11 +21,13 @@
 //! Module for POD (plain old data) structs.
 
 mod backlinks;
+mod karma;
 mod page_info;
 mod page_ref;
 mod user_info;
 
 pub use self::backlinks::Backlinks;
+pub use self::karma::KarmaLevel;
 pub use self::page_info::PageInfo;
 pub use self::page_ref::{PageRef, PageRefParseError};
 pub use self::user_info::UserInfo;
