@@ -2,7 +2,7 @@
  * includes/includer/debug.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -67,7 +67,7 @@ impl<'t> Includer<'t> for DebugIncluder {
 
     #[inline]
     fn no_such_include(&mut self, page_ref: &PageRef<'t>) -> Result<Cow<'t, str>, Void> {
-        Ok(Cow::Owned(format!("<MISSING-PAGE {}>", page_ref)))
+        Ok(Cow::Owned(format!("<MISSING-PAGE {page_ref}>")))
     }
 }
 
@@ -126,10 +126,11 @@ fn map_wrap() {
             };
 
             let actual = MapWrap(&input).to_string();
+            let expected = $expected;
 
-            println!("Input:    {}", raw_input);
-            println!("Actual:   {}", actual);
-            println!("Expected: {}", $expected);
+            println!("Input:    {raw_input}");
+            println!("Actual:   {actual}");
+            println!("Expected: {expected}");
             println!();
 
             assert_eq!(
