@@ -2,7 +2,7 @@
  * lib.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#![deny(missing_debug_implementations, unsafe_code)]
+#![forbid(unsafe_code)]
+#![deny(missing_debug_implementations)]
 
 //! A library to parse Wikidot text and produce an abstract syntax tree (AST).
 //!
@@ -49,31 +50,16 @@
 //! plain text and full HTML respectively.
 //!
 //! # Features
-//! This crate has several features of note.
+//! This crate has one feature of note:
 //!
-//! By default the `ffi` and `log` features are enabled.
-//! These enable support for FFI interfacing for the library
-//! via [`cbindgen`] (with a slightly more limited interface),
-//! and logging via [`slog`] respectively.
-//!
-//! If the `log` feature is enabled, then all calls requiring
-//! a `Logger` are replaced with a stub, and all actual logging
-//! calls are replaced with no-ops. Generally you want this
-//! for very performance-sensitive contexts where logging is
-//! simply not worth the overhead.
+//! The `mathml` feature pulls in the `latex2mathml` library,
+//! which renders LaTeX blocks using MathML. It is enabled
+//! by default.
 //!
 //! # Targets
 //! The library supports being compiled into WebAssembly.
 //! (target `wasm32-unknown-unknown`, see [`wasm-pack`] for more information)
 //!
-//! This adds the feature `wasm-log`, which adds `slog` logging support via
-//! `console.log()` calls to the browser's console. This is very useful for
-//! debugging, but caveat emptor! This spams the console very hard and can cause
-//! lag on some browsers. Do not enable in production.
-//!
-//! Additionally, disabling `log` as a feature compiles out all logging, similar
-//! to the default target.
-//!
 //! Compiling to wasm also disables all FFI integration,
 //! since these are inherently incompatible.
 //!
@@ -87,8 +73,6 @@
 //! [`TextRender`]: ./render/html/struct.HtmlRender.html
 //! [`HtmlRender`]: ./render/text/struct.TextRender.html
 //! [`serde`]: https://docs.rs/serde
-//! [`cbindgen`]: https://docs.rs/cbindgen
-//! [`slog`]: https://docs.rs/slog
 //! [`wasm-pack`]: https://rustwasm.github.io/docs/wasm-pack/
 
 // Only list crates which we want global macro imports.
@@ -103,6 +87,9 @@ extern crate enum_map;
 #[macro_use]
 extern crate lazy_static;
 
+#[macro_use]
+extern crate log;
+
 #[macro_use]
 extern crate maplit;
 
@@ -118,49 +105,34 @@ extern crate serde_repr;
 #[macro_use]
 extern crate str_macro;
 
-#[cfg(feature = "log")]
-#[macro_use]
-extern crate slog;
-
 // Library top-level modules
 
 #[cfg(test)]
 mod test;
 
-#[macro_use]
-mod log;
-
 #[macro_use]
 mod macros;
 
-mod data;
+mod id_prefix;
 mod next_index;
 mod non_empty_vec;
 mod preproc;
-mod span_wrap;
 mod text;
 mod url;
 mod utf16;
 
-#[cfg(feature = "ffi")]
-#[cfg(not(target_arch = "wasm32"))]
-pub mod ffi;
-
 #[cfg(target_arch = "wasm32")]
 pub mod wasm;
 
+pub mod data;
 pub mod includes;
 pub mod info;
 pub mod parsing;
 pub mod render;
+pub mod settings;
 pub mod tokenizer;
 pub mod tree;
 
-#[cfg(test)]
-#[cfg(feature = "log")]
-pub use self::log::{build_logger, build_null_logger, build_terminal_logger};
-
-pub use self::data::*;
 pub use self::includes::include;
 pub use self::parsing::parse;
 pub use self::preproc::preprocess;
@@ -168,10 +140,15 @@ pub use self::tokenizer::{tokenize, Tokenization};
 pub use self::utf16::Utf16IndexMap;
 
 pub mod prelude {
+    pub use super::data::PageInfo;
     pub use super::includes::{include, Includer};
     pub use super::parsing::{parse, ParseResult, ParseWarning};
+    pub use super::preprocess;
     pub use super::render::Render;
+    pub use super::settings::{
+        InterwikiSettings, WikitextMode, WikitextSettings, DEFAULT_INTERWIKI,
+        EMPTY_INTERWIKI,
+    };
     pub use super::tokenizer::{tokenize, Tokenization};
     pub use super::tree::{Element, SyntaxTree};
-    pub use super::{preprocess, PageInfo};
 }
