@@ -2,7 +2,7 @@
  * parsing/collect/text.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -27,7 +27,6 @@ use super::prelude::*;
 /// rather than considering them as special elements.
 #[inline]
 pub fn collect_text<'p, 'r, 't>(
-    log: &Logger,
     parser: &'p mut Parser<'r, 't>,
     rule: Rule,
     close_conditions: &[ParseCondition],
@@ -38,7 +37,6 @@ where
     'r: 't,
 {
     collect_text_keep(
-        log,
         parser,
         rule,
         close_conditions,
@@ -52,8 +50,9 @@ where
 ///
 /// The last token terminating the collection is kept, and returned
 /// to the caller alongside the string slice.
+///
+/// Compare with `collect_consume_keep()`.
 pub fn collect_text_keep<'p, 'r, 't>(
-    log: &Logger,
     parser: &'p mut Parser<'r, 't>,
     rule: Rule,
     close_conditions: &[ParseCondition],
@@ -64,10 +63,7 @@ where
     'r: 't,
 {
     // Log collect_text() call
-    info!(
-        log,
-        "Trying to consume tokens to merge into a single string",
-    );
+    info!("Trying to consume tokens to merge into a single string");
 
     let (start, mut end) = (parser.current(), None);
 
@@ -75,14 +71,13 @@ where
     //
     // We know text is always paragraph safe, so we ignore that value.
     let (last, exceptions, _) = collect(
-        log,
         parser,
         rule,
         close_conditions,
         invalid_conditions,
         warn_kind,
-        |log, parser| {
-            debug!(log, "Ingesting token in string span");
+        |parser| {
+            debug!("Ingesting token in string span");
 
             end = Some(parser.current());
             ok!(true; ())
@@ -97,7 +92,7 @@ where
 
     let slice = match (start, end) {
         // We have a token span, use to get string slice
-        (start, Some(end)) => parser.full_text().slice(log, start, end),
+        (start, Some(end)) => parser.full_text().slice(start, end),
 
         // Empty list of tokens, resultant slice must be empty
         (_, None) => "",
