@@ -2,7 +2,7 @@
  * parsing/paragraph/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -27,7 +27,6 @@ use super::parser::Parser;
 use super::prelude::*;
 use super::rule::Rule;
 use super::token::Token;
-use crate::log::prelude::*;
 
 /// Wrapper type to satisfy the issue with generic closure types.
 ///
@@ -50,7 +49,6 @@ type CloseConditionFn = fn(&mut Parser) -> Result<bool, ParseWarning>;
 /// It may produce multiple or none. Instead the logic iterates
 /// and produces paragraphs or child elements as needed.
 pub fn gather_paragraphs<'r, 't, F>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     rule: Rule,
     mut close_condition_fn: Option<F>,
@@ -59,13 +57,13 @@ where
     'r: 't,
     F: FnMut(&mut Parser<'r, 't>) -> Result<bool, ParseWarning>,
 {
-    info!(log, "Gathering paragraphs until ending");
+    info!("Gathering paragraphs until ending");
 
     // Update parser rule
     parser.set_rule(rule);
 
     // Create paragraph stack
-    let mut stack = ParagraphStack::new(log);
+    let mut stack = ParagraphStack::new();
 
     loop {
         let (elements, mut exceptions, paragraph_safe) = match parser.current().token {
@@ -76,25 +74,20 @@ where
                     //
                     // Pass a warning up the chain
 
-                    warn!(log, "Hit the end of input, producing warning");
-
+                    warn!("Hit the end of input, producing warning");
                     return Err(parser.make_warn(ParseWarningKind::EndOfInput));
                 } else {
                     // Avoid an unnecessary Element::Null and just exit
                     // If there's no close condition, then this is not a warning
 
-                    warn!(log, "Hit the end of input, terminating token iteration");
-
+                    warn!("Hit the end of input, terminating token iteration");
                     break;
                 }
             }
 
             // If we've hit a paragraph break, then finish the current paragraph
             Token::ParagraphBreak => {
-                info!(
-                    log,
-                    "Hit a paragraph break, creating a new paragraph container",
-                );
+                info!("Hit a paragraph break, creating a new paragraph container");
 
                 // Paragraph break -- end the paragraph and start a new one!
                 stack.end_paragraph();
@@ -110,23 +103,19 @@ where
             _ => {
                 if let Some(ref mut close_condition_fn) = close_condition_fn {
                     if close_condition_fn(parser).unwrap_or(false) {
-                        info!(
-                            log,
-                            "Hit closing condition for paragraphs, terminating token iteration",
-                        );
-
+                        info!("Hit closing condition for paragraphs, terminating token iteration");
                         break;
                     }
                 }
 
                 // Otherwise, produce consumption from this token pointer
-                debug!(log, "Trying to consume tokens to produce element");
-                consume(log, parser)
+                debug!("Trying to consume tokens to produce element");
+                consume(parser)
             }
         }?
         .into();
 
-        debug!(log, "Tokens consumed to produce element");
+        debug!("Tokens consumed to produce element");
 
         // Add new elements to the list
         push_elements(&mut stack, elements, paragraph_safe);
