@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/anchor.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -32,25 +32,17 @@ pub const BLOCK_ANCHOR: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing anchor block";
-        "in-head" => in_head,
-        "name" => name,
-        "star" => flag_star,
-    );
-
+    info!("Parsing anchor block (name '{name}', in-head {in_head}, star {flag_star})");
     assert_block_name(&BLOCK_ANCHOR, name);
 
     let arguments = parser.get_head_map(&BLOCK_ANCHOR, in_head)?;
-    let attributes = arguments.to_attribute_map();
+    let attributes = arguments.to_attribute_map(parser.settings());
 
     // "a" means we wrap interpret as-is
     // "a_" means we strip out any newlines or paragraph breaks
