@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/div.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -30,21 +30,13 @@ pub const BLOCK_DIV: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing div block";
-        "flag-score" => flag_score,
-        "in-head" => in_head,
-        "name" => name,
-    );
-
+    info!("Parsing div block (name '{name}', in-head {in_head}, score {flag_score})");
     assert!(!flag_star, "Div doesn't allow star flag");
     assert_block_name(&BLOCK_DIV, name);
 
@@ -64,7 +56,7 @@ fn parse_fn<'r, 't>(
     let element = Element::Container(Container::new(
         ContainerType::Div,
         elements,
-        arguments.to_attribute_map(),
+        arguments.to_attribute_map(parser.settings()),
     ));
 
     ok!(element, exceptions)
