@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/iframe.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -30,15 +30,13 @@ pub const BLOCK_IFRAME: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Parsing iframe block"; "in-head" => in_head);
-
+    info!("Parsing iframe block (in-head {in_head})");
     assert!(!flag_star, "iframe doesn't allow star flag");
     assert!(!flag_score, "iframe doesn't allow score flag");
     assert_block_name(&BLOCK_IFRAME, name);
@@ -46,7 +44,7 @@ fn parse_fn<'r, 't>(
     let (url, arguments) = parser.get_head_name_map(&BLOCK_IFRAME, in_head)?;
     let element = Element::Iframe {
         url: cow!(url),
-        attributes: arguments.to_attribute_map(),
+        attributes: arguments.to_attribute_map(parser.settings()),
     };
 
     ok!(element)
