@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/lines.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -31,21 +31,18 @@ pub const BLOCK_LINES: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Parsing newlines block"; "in-head" => in_head);
-
+    info!("Parsing newlines block (in-head {in_head})");
     assert!(!flag_star, "Lines doesn't allow star flag");
     assert!(!flag_score, "Lines doesn't allow score flag");
     assert_block_name(&BLOCK_LINES, name);
 
     let count = parser.get_head_value(&BLOCK_LINES, in_head, parse_count)?;
-
     ok!(Element::LineBreaks(count))
 }
 
@@ -60,18 +57,12 @@ fn parse_count<'r, 't>(
 
     match argument.parse::<NonZeroU32>() {
         Ok(value) if value.get() > 100 => {
-            warn!(
-                &parser.log(),
-                "Number of lines is too great (max 100)";
-                "lines" => value.get(),
-            );
-
+            warn!("Number of lines ({}) is too great (max 100)", value.get());
             Err(parser.make_warn(ParseWarningKind::BlockMalformedArguments))
         }
         Ok(value) => Ok(value),
-        Err(_error) => {
-            warn!(&parser.log(), "Invalid numeric expression: {}", _error);
-
+        Err(error) => {
+            warn!("Invalid numeric expression: {error}");
             Err(parser.make_warn(ParseWarningKind::BlockMalformedArguments))
         }
     }
