@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -20,7 +20,6 @@
 
 mod prelude {
     pub use super::super::{Arguments, BlockRule};
-    pub use crate::log::prelude::*;
     pub use crate::parsing::collect::*;
     pub use crate::parsing::condition::ParseCondition;
     pub use crate::parsing::parser::Parser;
@@ -41,8 +40,7 @@ mod prelude {
         }
 
         panic!(
-            "Actual {} name doesn't match any expected: {:?} (was {})",
-            name_type, expected_names, actual_name,
+            "Actual {name_type} name doesn't match any expected: {expected_names:?} (was {actual_name})",
         );
     }
 
@@ -71,8 +69,11 @@ mod checkbox;
 mod code;
 mod collapsible;
 mod css;
+mod date;
 mod del;
 mod div;
+mod embed;
+mod equation_ref;
 mod footnote;
 mod hidden;
 mod html;
@@ -89,6 +90,7 @@ mod later;
 mod lines;
 mod list;
 mod mark;
+mod math;
 mod module;
 mod monospace;
 mod paragraph;
@@ -99,6 +101,8 @@ mod strikethrough;
 mod subscript;
 mod superscript;
 mod table;
+mod tabs;
+mod target;
 mod toc;
 mod underline;
 mod user;
@@ -115,8 +119,11 @@ pub use self::checkbox::BLOCK_CHECKBOX;
 pub use self::code::BLOCK_CODE;
 pub use self::collapsible::BLOCK_COLLAPSIBLE;
 pub use self::css::BLOCK_CSS;
+pub use self::date::BLOCK_DATE;
 pub use self::del::BLOCK_DEL;
 pub use self::div::BLOCK_DIV;
+pub use self::embed::BLOCK_EMBED;
+pub use self::equation_ref::BLOCK_EQUATION_REF;
 pub use self::footnote::{BLOCK_FOOTNOTE, BLOCK_FOOTNOTE_BLOCK};
 pub use self::hidden::BLOCK_HIDDEN;
 pub use self::html::BLOCK_HTML;
@@ -131,8 +138,9 @@ pub use self::invisible::BLOCK_INVISIBLE;
 pub use self::italics::BLOCK_ITALICS;
 pub use self::later::BLOCK_LATER;
 pub use self::lines::BLOCK_LINES;
-pub use self::list::*;
+pub use self::list::{BLOCK_LI, BLOCK_OL, BLOCK_UL};
 pub use self::mark::BLOCK_MARK;
+pub use self::math::BLOCK_MATH;
 pub use self::module::BLOCK_MODULE;
 pub use self::monospace::BLOCK_MONOSPACE;
 pub use self::paragraph::BLOCK_PARAGRAPH;
@@ -145,6 +153,8 @@ pub use self::superscript::BLOCK_SUPERSCRIPT;
 pub use self::table::{
     BLOCK_TABLE, BLOCK_TABLE_CELL_HEADER, BLOCK_TABLE_CELL_REGULAR, BLOCK_TABLE_ROW,
 };
+pub use self::tabs::{BLOCK_TAB, BLOCK_TABVIEW};
+pub use self::target::BLOCK_TARGET;
 pub use self::toc::BLOCK_TABLE_OF_CONTENTS;
 pub use self::underline::BLOCK_UNDERLINE;
 pub use self::user::BLOCK_USER;
