@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/module/parser.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -27,12 +27,7 @@ where
 {
     #[inline]
     pub fn set_module(&mut self, module_rule: &ModuleRule) {
-        info!(
-            &self.log(),
-            "Running module rule {} for these tokens",
-            module_rule.name;
-        );
-
+        info!("Running module rule {} for these tokens", module_rule.name);
         self.set_rule(module_rule.rule());
     }
 }
