@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/module/rule.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -31,15 +31,14 @@ pub const BLOCK_MODULE: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Parsing module block"; "in-head" => in_head);
-
+    info!("Parsing module block (in-head {in_head})");
+    parser.check_page_syntax()?;
     assert!(!flag_star, "Module doesn't allow star flag");
     assert!(!flag_score, "Module doesn't allow score flag");
     assert_block_name(&BLOCK_MODULE, name);
@@ -62,7 +61,7 @@ fn parse_fn<'r, 't>(
     // If the module accepts a body, it should consume it,
     // then the tail. Otherwise it shouldn't move the token pointer.
     let (module, exceptions, paragraph_safe) =
-        (module_rule.parse_fn)(log, parser, subname, arguments)?.into();
+        (module_rule.parse_fn)(parser, subname, arguments)?.into();
 
     debug_assert_eq!(
         paragraph_safe,
