@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/paragraph.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -31,27 +31,20 @@ pub const BLOCK_PARAGRAPH: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing paragraph block";
-        "in-head" => in_head,
-        "name" => name,
-    );
-
+    info!("Parsing paragraph block (name '{name}', in-head {in_head})");
     assert!(!flag_star, "Paragraph doesn't allow star flag");
     assert!(!flag_score, "Paragraph doesn't allow score flag");
     assert_block_name(&BLOCK_PARAGRAPH, name);
 
     // Gather paragraphs
     let arguments = parser.get_head_map(&BLOCK_PARAGRAPH, in_head)?;
-    let attributes = arguments.to_attribute_map();
+    let attributes = arguments.to_attribute_map(parser.settings());
     let (mut elements, exceptions, _) =
         parser.get_body_elements(&BLOCK_PARAGRAPH, true)?.into();
 
