@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/size.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -32,27 +32,20 @@ pub const BLOCK_SIZE: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing size block";
-        "in-head" => in_head,
-        "name" => name,
-    );
-
+    info!("Parsing size block (name '{name}', in-head {in_head})");
     assert!(!flag_star, "Size doesn't allow star flag");
     assert!(!flag_score, "Size doesn't allow score flag");
     assert_block_name(&BLOCK_SIZE, name);
 
     let size =
         parser.get_head_value(&BLOCK_SIZE, in_head, |parser, value| match value {
-            Some(size) => Ok(format!("font-size: {};", size)),
+            Some(size) => Ok(format!("font-size: {size};")),
             None => Err(parser.make_warn(ParseWarningKind::BlockMissingArguments)),
         })?;
 
