@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/user.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -30,20 +30,13 @@ pub const BLOCK_USER: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing user block";
-        "in-head" => in_head,
-        "name" => name,
-    );
-
+    info!("Parsing user block (name '{name}', in-head {in_head})");
     assert!(!flag_score, "User doesn't allow score flag");
     assert_block_name(&BLOCK_USER, name);
 
