@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/mapping.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -22,7 +22,7 @@ use super::{blocks::*, BlockRule};
 use std::collections::HashMap;
 use unicase::UniCase;
 
-pub const BLOCK_RULES: [BlockRule; 49] = [
+pub const BLOCK_RULES: [BlockRule; 56] = [
     BLOCK_ALIGN_CENTER,
     BLOCK_ALIGN_JUSTIFY,
     BLOCK_ALIGN_LEFT,
@@ -35,8 +35,11 @@ pub const BLOCK_RULES: [BlockRule; 49] = [
     BLOCK_CODE,
     BLOCK_COLLAPSIBLE,
     BLOCK_CSS,
+    BLOCK_DATE,
     BLOCK_DEL,
     BLOCK_DIV,
+    BLOCK_EMBED,
+    BLOCK_EQUATION_REF,
     BLOCK_FOOTNOTE,
     BLOCK_FOOTNOTE_BLOCK,
     BLOCK_HIDDEN,
@@ -54,6 +57,7 @@ pub const BLOCK_RULES: [BlockRule; 49] = [
     BLOCK_LI,
     BLOCK_LINES,
     BLOCK_MARK,
+    BLOCK_MATH,
     BLOCK_MODULE,
     BLOCK_MONOSPACE,
     BLOCK_OL,
@@ -64,11 +68,14 @@ pub const BLOCK_RULES: [BlockRule; 49] = [
     BLOCK_STRIKETHROUGH,
     BLOCK_SUBSCRIPT,
     BLOCK_SUPERSCRIPT,
+    BLOCK_TAB,
     BLOCK_TABLE,
     BLOCK_TABLE_CELL_HEADER,
     BLOCK_TABLE_CELL_REGULAR,
     BLOCK_TABLE_OF_CONTENTS,
     BLOCK_TABLE_ROW,
+    BLOCK_TABVIEW,
+    BLOCK_TARGET,
     BLOCK_UL,
     BLOCK_UNDERLINE,
     BLOCK_USER,
