@@ -2,7 +2,7 @@
  * parsing/rule/impls/clear_float.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -28,16 +28,10 @@ pub const RULE_CLEAR_FLOAT: Rule = Rule {
 };
 
 fn try_consume_fn<'p, 'r, 't>(
-    log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
     let current = parser.current();
-
-    info!(
-        log,
-        "Consuming token to create a clear float";
-        "slice" => current.slice,
-    );
+    info!("Consuming token to create a clear float");
 
     let clear_float = match current.token {
         Token::ClearFloatBoth => ClearFloat::Both,
