@@ -2,7 +2,7 @@
  * parsing/rule/impls/text.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -27,12 +27,9 @@ pub const RULE_TEXT: Rule = Rule {
 };
 
 fn try_consume_fn<'p, 'r, 't>(
-    log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Consuming token as plain text element");
-
+    info!("Consuming token as plain text element");
     let ExtractedToken { slice, .. } = parser.current();
-
     ok!(text!(slice))
 }
