@@ -2,7 +2,7 @@
  * render/html/builder.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,6 @@
 use super::attributes::AddedAttributes;
 use super::context::HtmlContext;
 use super::render::ItemRender;
-use crate::log::prelude::*;
 use std::collections::HashSet;
 
 macro_rules! tag_method {
@@ -57,6 +56,7 @@ where
         HtmlBuilder { ctx }
     }
 
+    /// Create a new HTML element with the given tag type.
     #[inline]
     pub fn tag(self, tag: &'t str) -> HtmlBuilderTag<'c, 'i, 'h, 'e, 't> {
         debug_assert!(is_alphanumeric(tag));
@@ -65,6 +65,14 @@ where
         HtmlBuilderTag::new(ctx, tag)
     }
 
+    /// Create a new custom element. Tag must start with `wj-`.
+    #[inline]
+    pub fn element(self, tag: &'t str) -> HtmlBuilderTag<'c, 'i, 'h, 'e, 't> {
+        debug_assert!(tag.starts_with("wj-"));
+
+        self.tag(tag)
+    }
+
     #[inline]
     pub fn table_cell(self, header: bool) -> HtmlBuilderTag<'c, 'i, 'h, 'e, 't> {
         if header {
@@ -74,11 +82,34 @@ where
         }
     }
 
+    /// Creates an inline `<svg>` using the `ui.svg` spritesheet.
+    pub fn sprite(self, id: &'t str) {
+        let viewbox = match id {
+            "wj-karma" => "0 0 64 114",
+            _ => "0 0 24 24",
+        };
+
+        let class = format!("wj-sprite sprite-{id}");
+        let href = format!("/files--static/media/ui.svg#{id}");
+
+        self.tag("svg")
+            .attr(attr!(
+                "class" => &class,
+                "viewBox" => viewbox,
+            ))
+            .contents(|ctx| {
+                ctx.html().tag("use").attr(attr!("href" => &href));
+            });
+    }
+
     tag_method!(a);
     tag_method!(br);
-    tag_method!(button);
     tag_method!(code);
+    tag_method!(dd);
+    tag_method!(details);
     tag_method!(div);
+    tag_method!(dl);
+    tag_method!(dt);
     tag_method!(hr);
     tag_method!(iframe);
     tag_method!(img);
@@ -90,6 +121,7 @@ where
     tag_method!(span);
     tag_method!(sub);
     tag_method!(sup);
+    tag_method!(summary);
     tag_method!(table);
     tag_method!(tbody);
     tag_method!(tr);
@@ -139,6 +171,39 @@ impl<'c, 'i, 'h, 'e, 't> HtmlBuilderTag<'c, 'i, 'h, 'e, 't> {
         }
     }
 
+    fn attr_value(&mut self, value_parts: &[&str]) {
+        self.ctx.push_raw('"');
+
+        for part in value_parts {
+            self.ctx.push_escaped(part);
+        }
+
+        self.ctx.push_raw('"');
+    }
+
+    pub fn attr_single(&mut self, key: &str, value_parts: &[&str]) -> &mut Self {
+        // If value_parts is empty, then we just give the key.
+        //
+        // For instance, ("checked", &[]) in input produces
+        // <input checked> rather than <input checked="...">
+        //
+        // Alternatively, if it's only composed of empty strings,
+        // the same intent is signalled.
+        //
+        // Because .all() is true for empty slices, this expression
+        // checks both:
+
+        let has_value = !value_parts.iter().all(|s| s.is_empty());
+
+        self.attr_key(key, has_value);
+
+        if has_value {
+            self.attr_value(value_parts);
+        }
+
+        self
+    }
+
     pub fn attr(&mut self, attributes: AddedAttributes) -> &mut Self {
         fn filter_entries<'a>(
             attributes: &AddedAttributes<'a>,
@@ -196,33 +261,6 @@ impl<'c, 'i, 'h, 'e, 't> HtmlBuilderTag<'c, 'i, 'h, 'e, 't> {
         self
     }
 
-    pub fn attr_single(&mut self, key: &str, value_parts: &[&str]) -> &mut Self {
-        // If value_parts is empty, then we just give the key.
-        //
-        // For instance, ("checked", &[]) in input produces
-        // <input checked> rather than <input checked="...">
-        //
-        // Alternatively, if it's only composed of empty strings,
-        // the same intent is signalled.
-        //
-        // Because .all() is true for empty slices, this expression
-        // checks both:
-
-        let has_value = !value_parts.iter().all(|s| s.is_empty());
-
-        self.attr_key(key, has_value);
-
-        if has_value {
-            self.ctx.push_raw('"');
-            for part in value_parts {
-                self.ctx.push_escaped(part);
-            }
-            self.ctx.push_raw('"');
-        }
-
-        self
-    }
-
     fn content_start(&mut self) {
         if self.in_tag {
             self.ctx.push_raw('>');
@@ -234,9 +272,9 @@ impl<'c, 'i, 'h, 'e, 't> HtmlBuilderTag<'c, 'i, 'h, 'e, 't> {
     }
 
     #[inline]
-    pub fn inner<R: ItemRender>(&mut self, log: &Logger, item: R) -> &mut Self {
+    pub fn inner<R: ItemRender>(&mut self, item: R) -> &mut Self {
         self.content_start();
-        item.render(log, self.ctx);
+        item.render(self.ctx);
 
         self
     }
