@@ -2,7 +2,7 @@
  * render/html/element/input.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -22,21 +22,14 @@ use super::prelude::*;
 use crate::tree::AttributeMap;
 
 pub fn render_radio_button(
-    log: &Logger,
     ctx: &mut HtmlContext,
     name: &str,
     checked: bool,
     attributes: &AttributeMap,
 ) {
-    info!(
-        log,
-        "Creating radio button";
-        "name" => name,
-        "checked" => checked,
-    );
+    info!("Creating radio button (name '{name}', checked {checked})");
 
     ctx.html().input().attr(attr!(
-        "is" => "wj-radio",
         "name" => name,
         "type" => "radio",
         "checked"; if checked;;
@@ -44,20 +37,10 @@ pub fn render_radio_button(
     ));
 }
 
-pub fn render_checkbox(
-    log: &Logger,
-    ctx: &mut HtmlContext,
-    checked: bool,
-    attributes: &AttributeMap,
-) {
-    info!(
-        log,
-        "Creating checkbox";
-        "checked" => checked,
-    );
+pub fn render_checkbox(ctx: &mut HtmlContext, checked: bool, attributes: &AttributeMap) {
+    info!("Creating checkbox (checked {checked})");
 
     ctx.html().input().attr(attr!(
-        "is" => "wj-checkbox",
         "type" => "checkbox",
         "checked"; if checked;;
         attributes,
