@@ -2,7 +2,7 @@
  * render/html/element/list.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -22,39 +22,32 @@ use super::prelude::*;
 use crate::tree::{AttributeMap, ListItem, ListType};
 
 pub fn render_list(
-    log: &Logger,
     ctx: &mut HtmlContext,
     ltype: ListType,
     list_items: &[ListItem],
     attributes: &AttributeMap,
 ) {
     info!(
-        log,
-        "Rendering list";
-        "list-type" => ltype.name(),
-        "list-items-len" => list_items.len(),
+        "Rendering list '{}' (items {})",
+        ltype.name(),
+        list_items.len(),
     );
-
     let list_tag = ltype.html_tag();
     let mut tag = ctx.html().tag(list_tag);
 
-    tag.attr(attr!("is" => "wj-list";; attributes))
-        .contents(|ctx| {
-            for list_item in list_items {
-                match list_item {
-                    ListItem::Elements {
-                        elements,
-                        attributes,
-                    } => {
-                        ctx.html()
-                            .li()
-                            .attr(attr!("is" => "wj-list-item";; attributes))
-                            .inner(log, elements);
-                    }
-                    ListItem::SubList { element } => {
-                        render_element(log, ctx, element);
-                    }
+    tag.attr(attr!(;; attributes)).contents(|ctx| {
+        for list_item in list_items {
+            match list_item {
+                ListItem::Elements {
+                    elements,
+                    attributes,
+                } => {
+                    ctx.html().li().attr(attr!(;; attributes)).inner(elements);
+                }
+                ListItem::SubList { element } => {
+                    render_element(ctx, element);
                 }
             }
-        });
+        }
+    });
 }
