@@ -2,7 +2,7 @@
  * render/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -20,23 +20,25 @@
 
 mod prelude {
     pub use super::Render;
-    pub use crate::log::prelude::*;
+    pub use crate::data::PageInfo;
+    pub use crate::settings::{WikitextMode, WikitextSettings};
     pub use crate::tree::{AttributeMap, Container, ContainerType, Element, SyntaxTree};
-    pub use crate::PageInfo;
 }
 
 pub mod debug;
-pub mod html;
 pub mod json;
 pub mod null;
 pub mod text;
 
+#[cfg(feature = "html")]
+pub mod html;
+
 mod handle;
 
 use self::handle::{Handle, ModuleRenderMode};
-use crate::log::prelude::*;
+use crate::data::PageInfo;
+use crate::settings::WikitextSettings;
 use crate::tree::SyntaxTree;
-use crate::PageInfo;
 
 /// Abstract trait for any ftml renderer.
 ///
@@ -59,8 +61,8 @@ pub trait Render {
     /// it requires to produce the output string.
     fn render(
         &self,
-        log: &Logger,
-        page_info: &PageInfo,
         tree: &SyntaxTree,
+        page_info: &PageInfo,
+        settings: &WikitextSettings,
     ) -> Self::Output;
 }
