@@ -2,7 +2,7 @@
  * tree/attribute/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,9 @@
 mod safe;
 
 use super::clone::string_to_owned;
+use crate::id_prefix::isolate_ids;
 use crate::parsing::parse_boolean;
+use crate::settings::WikitextSettings;
 use std::borrow::Cow;
 use std::collections::{BTreeMap, HashMap};
 use std::fmt::{self, Debug};
@@ -91,6 +93,15 @@ impl<'t> AttributeMap<'t> {
         &self.inner
     }
 
+    pub fn isolate_id(&mut self, settings: &WikitextSettings) {
+        if settings.isolate_user_ids {
+            if let Some(value) = self.inner.get_mut("id") {
+                debug!("Found 'id' attribute, isolating value");
+                *value = Cow::Owned(isolate_ids(value));
+            }
+        }
+    }
+
     pub fn to_owned(&self) -> AttributeMap<'static> {
         let mut inner = BTreeMap::new();
 
