@@ -2,7 +2,7 @@
  * tree/container.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -173,15 +173,3 @@ impl ContainerType {
         }
     }
 }
-
-#[cfg(feature = "log")]
-impl slog::Value for ContainerType {
-    fn serialize(
-        &self,
-        _: &slog::Record,
-        key: slog::Key,
-        serializer: &mut dyn slog::Serializer,
-    ) -> slog::Result {
-        serializer.emit_str(key, self.name())
-    }
-}
