@@ -2,7 +2,7 @@
  * wasm/parsing.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -20,6 +20,7 @@
 
 use super::page_info::PageInfo;
 use super::prelude::*;
+use super::settings::WikitextSettings;
 use super::tokenizer::Tokenization;
 use crate::parsing::{
     ParseOutcome as RustParseOutcome, ParseWarning as RustParseWarning,
@@ -126,15 +127,19 @@ impl SyntaxTree {
 // Exported functions
 
 #[wasm_bindgen]
-pub fn parse(page_info: PageInfo, tokens: Tokenization) -> Result<ParseOutcome, JsValue> {
-    let log = &*LOGGER;
-
+pub fn parse(
+    tokens: Tokenization,
+    page_info: PageInfo,
+    settings: WikitextSettings,
+) -> Result<ParseOutcome, JsValue> {
     // Borrow and perform parsing
-    let page_info = page_info.get();
     let tokenization = tokens.get();
-    let (syntax_tree, warnings) = crate::parse(log, page_info, tokenization).into();
+    let page_info = page_info.get();
+    let settings = settings.get();
+    let (syntax_tree, warnings) = crate::parse(tokenization, page_info, settings).into();
 
-    // Deep-clone AST to make it owned, so it can be safely passed to JS.
+    // Deep-clone AST to make it owned, so it can be
+    // safely passed to JS, where it will live for an unknown time.
     let syntax_tree = syntax_tree.to_owned();
 
     // Convert warnings to use UTF-16 indices
@@ -146,6 +151,8 @@ pub fn parse(page_info: PageInfo, tokens: Tokenization) -> Result<ParseOutcome,
     Ok(ParseOutcome { inner })
 }
 
+// Utility functions
+
 fn convert_warnings_utf16(
     tokenization: &RustTokenization,
     warnings: Vec<RustParseWarning>,
@@ -158,6 +165,7 @@ fn convert_warnings_utf16(
 
     let full_text = tokenization.full_text().inner();
     let utf16_map = Utf16IndexMap::new(full_text);
+
     warnings
         .into_iter()
         .map(|warn| warn.to_utf16_indices(&utf16_map))
